summaryrefslogtreecommitdiffstats
path: root/ppapi
diff options
context:
space:
mode:
authorjvoung@google.com <jvoung@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2013-01-09 17:27:23 +0000
committerjvoung@google.com <jvoung@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2013-01-09 17:27:23 +0000
commit6294dd04a2ac9b6224029fec711566f38158bb19 (patch)
treebf54de25ee83dece02d6e89feb124eae9d4e1d52 /ppapi
parentf2d7606b43a355976bd659d1b6116eda2b40470b (diff)
downloadchromium_src-6294dd04a2ac9b6224029fec711566f38158bb19.zip
chromium_src-6294dd04a2ac9b6224029fec711566f38158bb19.tar.gz
chromium_src-6294dd04a2ac9b6224029fec711566f38158bb19.tar.bz2
Remove the socket_count parameter from NaCl Launch IPC messages.
After some refactoring, the socket_count is now hardcoded to 1, so we can assume there is only a single socket and avoid using a vector as well. BUG= http://code.google.com/p/nativeclient/issues/detail?id=3241 Review URL: https://codereview.chromium.org/11787029 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@175821 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ppapi')
-rw-r--r--ppapi/api/private/ppb_nacl_private.idl9
-rw-r--r--ppapi/c/private/ppb_nacl_private.h11
-rw-r--r--ppapi/native_client/src/trusted/plugin/nacl_entry_points.h3
-rw-r--r--ppapi/native_client/src/trusted/plugin/sel_ldr_launcher_chrome.cc3
4 files changed, 10 insertions, 16 deletions
diff --git a/ppapi/api/private/ppb_nacl_private.idl b/ppapi/api/private/ppb_nacl_private.idl
index aa65b97..f603d6b 100644
--- a/ppapi/api/private/ppb_nacl_private.idl
+++ b/ppapi/api/private/ppb_nacl_private.idl
@@ -37,9 +37,9 @@ enum PP_NaClError {
/* PPB_NaCl_Private */
interface PPB_NaCl_Private {
- /* Launches NaCl's sel_ldr process. Returns PP_NACL_OK on success and writes
- * |socket_count| nacl::Handles to imc_handles. Returns PP_NACL_FAILED on
- * failure. The |enable_ppapi_dev| parameter controls whether GetInterface
+ /* Launches NaCl's sel_ldr process. Returns PP_NACL_OK on success and
+ * writes a nacl::Handle to imc_handle. Returns PP_NACL_FAILED on failure.
+ * The |enable_ppapi_dev| parameter controls whether GetInterface
* returns 'Dev' interfaces to the NaCl plugin. The |uses_ppapi| flag
* indicates that the nexe run by sel_ldr will use the PPAPI APIs.
* This implies that LaunchSelLdr is run from the main thread. If a nexe
@@ -49,8 +49,7 @@ interface PPB_NaCl_Private {
[in] str_t alleged_url,
[in] PP_Bool uses_ppapi,
[in] PP_Bool enable_ppapi_dev,
- [in] int32_t socket_count,
- [out] mem_t imc_handles);
+ [out] mem_t imc_handle);
/* This function starts the IPC proxy so the nexe can communicate with the
* browser. Returns PP_NACL_OK on success, otherwise a result code indicating
diff --git a/ppapi/native_client/src/trusted/plugin/nacl_entry_points.h b/ppapi/native_client/src/trusted/plugin/nacl_entry_points.h
index aaa7d13..26507b1 100644
--- a/ppapi/native_client/src/trusted/plugin/nacl_entry_points.h
+++ b/ppapi/native_client/src/trusted/plugin/nacl_entry_points.h
@@ -20,8 +20,7 @@ typedef PP_NaClResult (*LaunchNaClProcessFunc)(PP_Instance instance,
const char* alleged_url,
PP_Bool uses_ppapi,
PP_Bool enable_ppapi_dev,
- int socket_count,
- nacl::Handle* result_sockets);
+ nacl::Handle* result_socket);
extern LaunchNaClProcessFunc launch_nacl_process;
diff --git a/ppapi/native_client/src/trusted/plugin/sel_ldr_launcher_chrome.cc b/ppapi/native_client/src/trusted/plugin/sel_ldr_launcher_chrome.cc
index 8da1aeb..0222558 100644
--- a/ppapi/native_client/src/trusted/plugin/sel_ldr_launcher_chrome.cc
+++ b/ppapi/native_client/src/trusted/plugin/sel_ldr_launcher_chrome.cc
@@ -21,13 +21,10 @@ bool SelLdrLauncherChrome::Start(PP_Instance instance,
if (!launch_nacl_process)
return false;
// send a synchronous message to the browser process
- // TODO(sehr): This is asserted to be one. Remove this parameter.
- static const int kNumberOfChannelsToBeCreated = 1;
if (launch_nacl_process(instance,
url,
PP_FromBool(uses_ppapi),
PP_FromBool(enable_ppapi_dev),
- kNumberOfChannelsToBeCreated,
&channel_) != PP_NACL_OK) {
return false;
}
diff --git a/ppapi/c/private/ppb_nacl_private.h b/ppapi/c/private/ppb_nacl_private.h
index 42a6a71..e89b548 100644
--- a/ppapi/c/private/ppb_nacl_private.h
+++ b/ppapi/c/private/ppb_nacl_private.h
@@ -3,7 +3,7 @@
* found in the LICENSE file.
*/
-/* From private/ppb_nacl_private.idl modified Thu Dec 13 13:40:29 2012. */
+/* From private/ppb_nacl_private.idl modified Mon Jan 7 12:49:31 2013. */
#ifndef PPAPI_C_PRIVATE_PPB_NACL_PRIVATE_H_
#define PPAPI_C_PRIVATE_PPB_NACL_PRIVATE_H_
@@ -62,9 +62,9 @@ typedef enum {
*/
/* PPB_NaCl_Private */
struct PPB_NaCl_Private_1_0 {
/* Launches NaCl's sel_ldr process. Returns PP_NACL_OK on success and writes
* |socket_count| nacl::Handles to imc_handles. Returns PP_NACL_FAILED on
* failure. The |enable_ppapi_dev| parameter controls whether GetInterface
* returns 'Dev' interfaces to the NaCl plugin. The |uses_ppapi| flag
* indicates that the nexe run by sel_ldr will use the PPAPI APIs.
* This implies that LaunchSelLdr is run from the main thread. If a nexe
@@ -74,8 +74,7 @@ struct PPB_NaCl_Private_1_0 {
const char* alleged_url,
PP_Bool uses_ppapi,
PP_Bool enable_ppapi_dev,
- int32_t socket_count,
- void* imc_handles);
+ void* imc_handle);
/* This function starts the IPC proxy so the nexe can communicate with the
* browser. Returns PP_NACL_OK on success, otherwise a result code indicating
* the failure. PP_NACL_FAILED is returned if LaunchSelLdr wasn't called with
@@ -62,9 +62,9 @@ typedef enum {
/* PPB_NaCl_Private */
struct PPB_NaCl_Private_1_0 {
- /* Launches NaCl's sel_ldr process. Returns PP_NACL_OK on success and writes
- * |socket_count| nacl::Handles to imc_handles. Returns PP_NACL_FAILED on
- * failure. The |enable_ppapi_dev| parameter controls whether GetInterface
+ /* Launches NaCl's sel_ldr process. Returns PP_NACL_OK on success and
+ * writes a nacl::Handle to imc_handle. Returns PP_NACL_FAILED on failure.
+ * The |enable_ppapi_dev| parameter controls whether GetInterface
* returns 'Dev' interfaces to the NaCl plugin. The |uses_ppapi| flag
* indicates that the nexe run by sel_ldr will use the PPAPI APIs.